#  Copyright (C) 2023
#  ABM, Moscow
#
#  UNPUBLISHED PROPRIETARY MATERIAL.
#  ALL RIGHTS RESERVED.
#
#  Authors: Revva Konstantin <k.revva@abm-jsc.ru>


from detector_connector import DetectorKafkaConnector

from .shift_definition import ShiftAnalyzeResult


class ShiftDetectorKafkaConnector(DetectorKafkaConnector):
    Context = DetectorKafkaConnector.Context
    Config = DetectorKafkaConnector.Config

    def __init__(self, config: Config, context: Context):
        super().__init__(config=config, context=context, detector_analyze_result_type=ShiftAnalyzeResult)
